import { differenceInDays } from 'date-fns'
import { utcToZonedTime } from 'date-fns-tz'
import { computed, reactive, ref } from 'vue'

import { getEmptyOperation, isOperationReady } from '@/algo'
import {
  BXL_TZ,
  GAME_STARTING_DATE,
  GameDifficultyType,
  GameStateType,
} from '@/globals'
import { Operation, Plaquette } from '@/types'
import { getCurrentDate } from '@/utils'

export const gameState = ref(GameStateType.Undefined)
export const operations = reactive<Operation[]>([getEmptyOperation()])
export const plaquettes = ref<Plaquette[]>([])
export const result = ref(0)

// #region Difficulty-related values

export const gameDifficulty = ref(GameDifficultyType.Normal)

export const maxNumberOfOperations = computed(() =>
  gameDifficulty.value === GameDifficultyType.Hard ? 5 : 4,
)

export const startingNumberOfPlaquettes = computed(() =>
  gameDifficulty.value === GameDifficultyType.Hard ? 6 : 5,
)

export const isHardMode = computed(
  () => gameDifficulty.value === GameDifficultyType.Hard,
)

// #endregion Difficulty-related constants

export const currentOperation = computed(
  () => operations[operations.length - 1],
)

export const gameIsRunning = computed(
  () => gameState.value > GameStateType.Loading,
)
export const isEndGame = computed(
  () =>
    (operations.length === maxNumberOfOperations.value &&
      isOperationReady(currentOperation.value)) ||
    isResultPerfect.value,
)

export const isResultPerfect = computed(
  () => !!operations.some(o => o.result?.value === result.value),
)

export function numberOfGamesSinceStart(): number {
  const startDate = utcToZonedTime(
    new Date(GAME_STARTING_DATE as string),
    BXL_TZ,
  )
  return differenceInDays(getCurrentDate(), startDate)
}

export function clearOperationsList(): void {
  operations.splice(0)
  operations.push(getEmptyOperation())
}
