import { ref, watch } from 'vue'

import { LSK_DARKMODE, LSK_LOCALE } from '@/globals'
import { i18n } from '@/i18n'
import { getItem, setItem } from '@/storage'

// #region Dark Mode

export const darkMode = ref(getItem(LSK_DARKMODE, 'true') === 'true')
watch(
  darkMode,
  val => {
    if (val) {
      document.documentElement.classList.add('dark')
    }
    else {
      document.documentElement.classList.remove('dark')
    }
    setItem(LSK_DARKMODE, val ? 'true' : 'false')
  },
  { immediate: true },
)

export function isDarkModeDefault(): boolean {
  return (
    window.matchMedia &&
    window.matchMedia('(prefers-color-scheme: dark)').matches
  )
}

// #endregion Dark mode

// #region Locale

export const isLocaleFrench = ref(getItem(LSK_LOCALE, 'en') === 'fr')
watch(
  isLocaleFrench,
  v => {
    setItem(LSK_LOCALE, v ? 'fr' : 'en')
    i18n.global.locale.value = v ? 'fr' : 'en'
  },
  { immediate: true },
)

// #endregion Locale
