import { i18n } from '@/i18n'
import { percentageDiff, setDailyPRNG, shuffle } from '@/utils'

import {
  isHardMode,
  numberOfGamesSinceStart,
  operations,
  plaquettes,
  result,
} from './game-state'
import { showToast } from './toast-manager'

function getSharingText(): string {
  setDailyPRNG()
  const baseSymbols = shuffle(['🟢', '🔴', '🟠', '🟡', '🟣', '🔵'])
  const resultSymbols = shuffle(['🟩', '🟥', '🟧', '🟨', '🟪', '🟦'])

  for (const item of plaquettes.value) {
    item.symbol = item.original ? baseSymbols.shift() : resultSymbols.pop()
  }

  // × ÷ + -
  const endResult = operations[operations.length - 1].result?.value ?? 0
  const lines: string[] = []
  for (const op of operations) {
    // let s = ''
    // switch (op.operator) {
    //   case '*':
    //     s = '✖'
    //     break
    //   case '/':
    //     s = '➗'
    //     break
    //   case '-':
    //     s = '➖'
    //     break
    //   case '+':
    //     s = '➕'
    //     break
    // }
    let s = ''
    switch (op.operator) {
      case '*':
        s = '×'
        break
      case '/':
        s = '÷'
        break
      case '-':
        s = '-'
        break
      case '+':
        s = '+'
        break
    }
    lines.push(
      `${op.left?.symbol} ${s} ${op.right?.symbol} = ${
        op.result?.value === endResult ? endResult : op.result?.symbol
      }`,
    )
  }

  return `N0mbers #${numberOfGamesSinceStart()} - ${isHardMode.value ? 'Advanced' : 'Normal'}
${lines.join('\n')} ${result.value === endResult ? '✔' : '❌'}
https://n0mbers.scambier.xyz`
}

export function toClipboard(): void {
  navigator.clipboard.writeText(getSharingText())
  showToast(i18n.global.t('copiedInClipboard'), 3000)
}
